netapp_ontap.models.nas_application_components API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.nas_application_components`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class NasApplicationComponentsSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the NasApplicationComponents object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `export_policy GET POST`

    The export_policy field of the nas_application_components.

  `flexcache GET POST`

    The flexcache field of the nas_application_components.

  `name GET POST PATCH`

    The name of the application component.

  `qos GET POST`

    The qos field of the nas_application_components.

  `scale_out GET POST`

    Denotes a Flexgroup.

  `share_count GET POST`

    The number of shares in the application component.

  `storage_service GET POST PATCH`

    The storage_service field of the nas_application_components.

  `tiering GET POST PATCH`

    The tiering field of the nas_application_components.

  `total_size GET POST PATCH`

    The total size of the application component, split across the member shares. Usage: {<integer>[KB|MB|GB|TB|PB]}